@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-#TODO: """DocString if there is one"""
+# TODO: """DocString if there is one"""
 
 import math
 import textwrap
@@ -20,8 +20,8 @@ import epyqlib.utils.qt
 import epyqlib.utils.twisted
 
 # See file COPYING in this source tree
-__copyright__ = 'Copyright 2017, EPC Power Corp.'
-__license__ = 'GPLv2+'
+__copyright__ = "Copyright 2017, EPC Power Corp."
+__license__ = "GPLv2+"
 
 
 class UnsupportedError(Exception):
@@ -31,10 +31,7 @@ class UnsupportedError(Exception):
 def load_device(bus=None, file=None, parent=None):
     # TODO  CAMPid 9561616237195401795426778
     if file is None:
-        filters = [
-            ('EPC Packages', ['epc', 'epz']),
-            ('All Files', ['*'])
-        ]
+        filters = [("EPC Packages", ["epc", "epz"]), ("All Files", ["*"])]
         file = epyqlib.utils.qt.file_dialog(filters, parent=parent)
 
         if file is None:
@@ -67,9 +64,7 @@ class DeviceTreeView(QtWidgets.QWidget):
         )
 
         self.ui.tree_view.setContextMenuPolicy(Qt.CustomContextMenu)
-        self.ui.tree_view.customContextMenuRequested.connect(
-            self.context_menu
-        )
+        self.ui.tree_view.customContextMenuRequested.connect(self.context_menu)
 
         self.model = None
 
@@ -97,33 +92,33 @@ class DeviceTreeView(QtWidgets.QWidget):
 
         menu = QMenu()
         if isinstance(node, epyqlib.devicetree.Device):
-            offline = (not node.tree_parent._checked.name
-                      and not node.tree_parent.fields.name == 'Offline')
+            offline = (
+                not node.tree_parent._checked.name
+                and not node.tree_parent.fields.name == "Offline"
+            )
 
-            pull_raw_log_action = menu.addAction('Pull Raw Log...')
+            pull_raw_log_action = menu.addAction("Pull Raw Log...")
             pull_raw_log_action.setEnabled(offline)
 
-            write_to_epz_action = menu.addAction('Write To Epz...')
+            write_to_epz_action = menu.addAction("Write To Epz...")
             write_to_epz_action.setEnabled(not node.device.from_zip)
             # TODO: stdlib zipfile can't create an encrypted .zip
             #       make a good solution that will...
             write_to_epz_action.setVisible(False)
 
-            check_compatibility_action = menu.addAction('Check Compatibility')
+            check_compatibility_action = menu.addAction("Check Compatibility")
             check_compatibility_action.setEnabled(not offline)
 
-            remove_device_action = menu.addAction('Close')
+            remove_device_action = menu.addAction("Close")
         if isinstance(node, epyqlib.devicetree.Bus):
-            add_device_action = menu.addAction('Open device file...')
-            flash_action = menu.addAction('Load firmware...')
+            add_device_action = menu.addAction("Open device file...")
+            flash_action = menu.addAction("Load firmware...")
             flash_action.setEnabled(
-                not node._checked.name
-                and not node.fields.name == 'Offline'
+                not node._checked.name and not node.fields.name == "Offline"
             )
-            blink_action = menu.addAction('Blink adapter')
+            blink_action = menu.addAction("Blink adapter")
             blink_action.setEnabled(
-                node.interface == 'pcan'
-                and node.bus.bus is not None
+                node.interface == "pcan" and node.bus.bus is not None
             )
 
         action = menu.exec_(self.ui.tree_view.viewport().mapToGlobal(position))
@@ -137,10 +132,10 @@ class DeviceTreeView(QtWidgets.QWidget):
             if device is not None:
                 self.ui.tree_view.selectionModel().setCurrentIndex(
                     self.model.index_from_node(device),
-                    QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows)
+                    QItemSelectionModel.ClearAndSelect | QItemSelectionModel.Rows,
+                )
         elif action is flash_action:
-            self.flash(interface=node.interface,
-                       channel=node.channel)
+            self.flash(interface=node.interface, channel=node.channel)
         elif action is pull_raw_log_action:
             self.pull_raw_log(node=node)
         elif action is write_to_epz_action:
@@ -157,40 +152,35 @@ class DeviceTreeView(QtWidgets.QWidget):
         shas = device.shas
         if len(shas) == 0:
             self.compatibility_notification(
-                message='No compatible revisions specified for this device.',
-                compatible=False
+                message="No compatible revisions specified for this device.",
+                compatible=False,
             )
         else:
             try:
-                signal = device.nvs.signal_from_names(
-                    'SoftwareHash', 'SoftwareHash')
+                signal = device.nvs.signal_from_names("SoftwareHash", "SoftwareHash")
             except epyqlib.nv.NotFoundError as e:
                 raise UnsupportedError(
-                    'Compatibility check is not supported for this device') from e
+                    "Compatibility check is not supported for this device"
+                ) from e
 
             d = device.nvs.protocol.read(signal)
             d.addCallback(self._check_compatibility, device=device)
             d.addErrback(epyqlib.utils.twisted.errbackhook)
 
     def _check_compatibility(self, value, device):
-        sha = '{:07x}'.format(int(value))
+        sha = "{:07x}".format(int(value))
 
         compatible = any(s.startswith(sha) for s in device.shas)
-        print('alskflasdfasdfaslkfdasdfjsdjfasdfsd')
+        print("alskflasdfasdfaslkfdasdfjsdjfasdfsd")
         print(sha)
         print(device.shas)
 
         if compatible:
-            message = ('Embedded SHA {} found in compatibility list.'
-                       .format(sha))
+            message = "Embedded SHA {} found in compatibility list.".format(sha)
         else:
-            message = ('Embedded SHA {} not found in compatibility list.'
-                       .format(sha))
+            message = "Embedded SHA {} not found in compatibility list.".format(sha)
 
-        self.compatibility_notification(
-            message=message,
-            compatible=compatible
-        )
+        self.compatibility_notification(message=message, compatible=compatible)
 
     def compatibility_notification(self, message, compatible):
         if compatible:
@@ -206,14 +196,14 @@ class DeviceTreeView(QtWidgets.QWidget):
 
     def pull_raw_log(self, node):
         bus_node = node.tree_parent
-        real_bus = can.interface.Bus(bustype=bus_node.interface,
-                                     channel=bus_node.channel,
-                                     bitrate=bus_node.bitrate)
-        bus = epyqlib.busproxy.BusProxy(bus=real_bus,
-                                        auto_disconnect=False)
+        real_bus = can.interface.Bus(
+            bustype=bus_node.interface,
+            channel=bus_node.channel,
+            bitrate=bus_node.bitrate,
+        )
+        bus = epyqlib.busproxy.BusProxy(bus=real_bus, auto_disconnect=False)
 
-        d = epyqlib.datalogger.pull_raw_log(
-            device=node.device, bus=bus, parent=self)
+        d = epyqlib.datalogger.pull_raw_log(device=node.device, bus=bus, parent=self)
         d.addBoth(epyqlib.utils.twisted.detour_result, bus.set_bus)
 
     def add_device(self, bus, device=None):
@@ -221,7 +211,7 @@ class DeviceTreeView(QtWidgets.QWidget):
             device = load_device(parent=self)
 
         if device is not None:
-            device.on_offline_bus = bus.fields.name == 'Offline'
+            device.on_offline_bus = bus.fields.name == "Offline"
             device = epyqlib.devicetree.Device(device=device)
 
             self.model.add_device(bus, device)
@@ -233,14 +223,12 @@ class DeviceTreeView(QtWidgets.QWidget):
 
     def flash(self, interface, channel):
         # TODO  CAMPid 9561616237195401795426778
-        filters = [
-            ('TICOFF Binaries', ['out']),
-            ('All Files', ['*'])
-        ]
+        filters = [("TICOFF Binaries", ["out"]), ("All Files", ["*"])]
         file = epyqlib.utils.qt.file_dialog(filters, parent=self)
 
         if file is not None:
-            text = textwrap.dedent('''\
+            text = textwrap.dedent(
+                """\
             Flashing {file}
 
             <ol>
@@ -277,11 +265,14 @@ class DeviceTreeView(QtWidgets.QWidget):
                 </ul>
               </li>
             </ol>
-            '''.format(file=file))
+            """.format(
+                    file=file
+                )
+            )
 
             accepted = epyqlib.utils.qt.dialog(
                 parent=self,
-                title='Flashing',
+                title="Flashing",
                 message=text,
                 icon=QtWidgets.QMessageBox.Information,
                 rich_text=True,
@@ -289,63 +280,71 @@ class DeviceTreeView(QtWidgets.QWidget):
             )
 
             if accepted:
-                with open(file, 'rb') as f:
-                    real_bus = can.interface.Bus(bustype=interface,
-                                                 channel=channel,
-                                                 bitrate=250000)
-                    bus = epyqlib.busproxy.BusProxy(bus=real_bus,
-                                                    auto_disconnect=False)
+                with open(file, "rb") as f:
+                    real_bus = can.interface.Bus(
+                        bustype=interface, channel=channel, bitrate=250000
+                    )
+                    bus = epyqlib.busproxy.BusProxy(bus=real_bus, auto_disconnect=False)
 
                     progress = epyqlib.utils.qt.progress_dialog(
-                        parent=self,
-                        cancellable=True
+                        parent=self, cancellable=True
                     )
 
-                    flasher = epyqlib.flash.Flasher(file=f,
-                                                    bus=bus,
-                                                    progress=progress,
-                                                    retries=math.inf,
-                                                    parent=self)
+                    flasher = epyqlib.flash.Flasher(
+                        file=f,
+                        bus=bus,
+                        progress=progress,
+                        retries=math.inf,
+                        parent=self,
+                    )
 
                     failed_box = QMessageBox(parent=self)
-                    failed_box.setText(textwrap.dedent('''\
+                    failed_box.setText(
+                        textwrap.dedent(
+                            """\
                     Flashing failed
-                    '''))
+                    """
+                        )
+                    )
 
                     canceled_box = QMessageBox(parent=self)
-                    canceled_box.setText(textwrap.dedent('''\
+                    canceled_box.setText(
+                        textwrap.dedent(
+                            """\
                     Flashing canceled
-                    '''))
+                    """
+                        )
+                    )
 
                     flasher.done.connect(progress.close)
                     flasher.done.connect(progress.deleteLater)
                     flasher.done.connect(bus.set_bus)
 
-                    completed_format = textwrap.dedent('''\
+                    completed_format = textwrap.dedent(
+                        """\
                     Flashing completed successfully
 
-                    Data time: {:.3f} seconds for {} bytes or {:.0f} bytes/second''')
-                    flasher.completed.connect(
-                        lambda f=flasher:
-                            print(
-                                completed_format.format(
-                                    f.data_delta_time,
-                                    f.download_bytes,
-                                    f.download_bytes / f.data_delta_time
-                                )
-                            )
+                    Data time: {:.3f} seconds for {} bytes or {:.0f} bytes/second"""
                     )
                     flasher.completed.connect(
-                        lambda f=flasher:
-                            QMessageBox.information(
-                                self,
-                                'EPyQ',
-                                completed_format.format(
-                                    f.data_delta_time,
-                                    f.download_bytes,
-                                    f.download_bytes / f.data_delta_time
-                                )
+                        lambda f=flasher: print(
+                            completed_format.format(
+                                f.data_delta_time,
+                                f.download_bytes,
+                                f.download_bytes / f.data_delta_time,
                             )
+                        )
+                    )
+                    flasher.completed.connect(
+                        lambda f=flasher: QMessageBox.information(
+                            self,
+                            "EPyQ",
+                            completed_format.format(
+                                f.data_delta_time,
+                                f.download_bytes,
+                                f.download_bytes / f.data_delta_time,
+                            ),
+                        )
                     )
                     flasher.failed.connect(failed_box.exec)
                     flasher.canceled.connect(canceled_box.exec)
@@ -360,19 +359,15 @@ class DeviceTreeView(QtWidgets.QWidget):
     def write_to_epz(self, device):
         print(device.referenced_files)
 
-        filters = [
-            ('EPZ', ['epz']),
-            ('All Files', ['*'])
-        ]
-        filename = epyqlib.utils.qt.file_dialog(
-            filters, save=True, parent=self)
+        filters = [("EPZ", ["epz"]), ("All Files", ["*"])]
+        filename = epyqlib.utils.qt.file_dialog(filters, save=True, parent=self)
 
         if filename is not None:
             epyqlib.utils.general.write_device_to_zip(
                 zip_path=filename,
-                epc_dir='',
+                epc_dir="",
                 referenced_files=device.referenced_files,
-                code=epyqlib.utils.qt.get_code()
+                code=epyqlib.utils.qt.get_code(),
             )
 
     def setModel(self, model):
@@ -384,31 +379,31 @@ class DeviceTreeView(QtWidgets.QWidget):
         for i, resize in enumerate(self.resize_columns):
             if resize:
                 self.ui.tree_view.header().setSectionResizeMode(
-                    i, QtWidgets.QHeaderView.ResizeToContents)
+                    i, QtWidgets.QHeaderView.ResizeToContents
+                )
 
         self.ui.tree_view.setItemDelegateForColumn(
             epyqlib.devicetree.Columns.indexes.bitrate,
-            epyqlib.delegates.ByFunction(model=model, parent=self)
+            epyqlib.delegates.ByFunction(model=model, parent=self),
         )
 
-        self.ui.tree_view.selectionModel().currentChanged.connect(
-            self._current_changed)
+        self.ui.tree_view.selectionModel().currentChanged.connect(self._current_changed)
 
-        widths = [self.ui.tree_view.columnWidth(i)
-                  for i in epyqlib.devicetree.Columns.indexes]
+        widths = [
+            self.ui.tree_view.columnWidth(i) for i in epyqlib.devicetree.Columns.indexes
+        ]
         width = sum(widths)
         width += 2 * self.ui.tree_view.frameWidth()
 
         self.ui.tree_view.setMinimumWidth(1.25 * width)
 
         self.ui.tree_view.header().setSectionResizeMode(
-            epyqlib.devicetree.Columns.indexes.name,
-            QHeaderView.Stretch
+            epyqlib.devicetree.Columns.indexes.name, QHeaderView.Stretch
         )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import sys
 
-    print('No script functionality here')
-    sys.exit(1)     # non-zero is a failure
+    print("No script functionality here")
+    sys.exit(1)  # non-zero is a failure
